package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````N!L``#0```#4H0````0`!30`(``)
M`"@`'0`<``$``'",D0``C)$``(R1``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!XD@``>)(```4`````$```
M`0```*"=``"@K0``H*T``*@"``"\`@``!@`````0```"````J)T``*BM``"H
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DH)T`
M`*"M``"@K0``8`(``&`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`\_9\3XJK2:FNBQ4H,`4HH`D[G>L$
M````$`````$```!'3E4```````,````"`````````&$```!L````````````
M``!:````0@``````````````"````````````````````#H`````````2P``
M`#D```!E`````````"P```!1````4@```#,```!B````:`````,````P````
M```````````C````1P```"X``````````````%,```!*````-P```$X```!?
M````:P```"$````'````"0`````````8`````````$````!C````4````#0`
M````````30```&0````V````#0```#L``````````````%L````R````20``
M`$8````J````````````````````/@```$0````````````````````6````
M#P`````````_````(@```"<```````````````H```!(````.````#P```!5
M`````````"\```!J````00````````````````````````!6`````````$,`
M``!8````*`````8````D````3```````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!7````````````````````````````````````%```````````
M````60`````````<`````````&8```!I`````````!\``````````````!D`
M````````9P```````````````````!L````.````(````"8````$````#```
M`!X````M```````````````=````3P``````````````5````"4```!=````
M&@```"L````7````"P```````````````````%P````Q````/0```!,```!%
M````7@````````````````````````````````````4`````````````````
M```U````````````````````$0```````````````````"D````5````````
M`!(`````````````````````````8````````````````````&$`````````
M`````!$```!.````"`````@````!D!`$)4`$@"B```6@AE"$@($``@LH!(PX
M@!)!B@``"$X```!/````4@```%8```!7````8````&$```!B`````````&0`
M``!E````9@```&<```!H````:P```````````````:\TZ&[%WQ_.WD<M:W^:
M?"[%F[;49-1\=E0\E"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=Y
MNN.2?/JA;&"93\.;:PE#UF>OS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@
MIP(*:AJ>4+_:5QNCX/M)``````````````````````````#T%0````````,`
M#````````+`````````#`!@`&@(`````````````$@```+X"````````````
M`!(```!G```````````````2````R```````````````$@````4"````````
M`````!(```!6`@`````````````2````I0(`````````````$@```'\`````
M`````````!(```#Y`@`````````````2`````0``````````````(````+(!
M`````````````!(```#P`@`````````````2````1@(`````````````$@``
M`#D#`````````````!(```!-`0`````````````2````S@$`````````````
M$@```!```````````````"````#6`@`````````````2````#`(`````````
M````$@```,,"`````````````!(``````@`````````````2````P0``````
M````````$@```"P``````````````"````"Z```````````````2````I0$`
M````````````$@```,@"`````````````!(````Q`0`````````````6````
M(0$`````````````$@````P#`````````````!(````0`0`````````````2
M````X0(`````````````$@```-H``````````````!(```#O````````````
M```2````U@$`````````````$@````D$`````````````!(```!B`0``````
M```````2````L0``````````````$0```#\"`````````````!(```!``P``
M```````````1````W0$`````````````$@```!,"`````````````!(```"P
M`@`````````````2````]@``````````````$@```+D!`````````````!(`
M``!W`@`````````````2````^`$`````````````$@```)X"````````````
M`!(```"6```````````````2````,0(`````````````$@```,`!````````
M`````!(```#_```````````````2````N0``````````````$@```&T`````
M`````````!(```!B`@`````````````2````G@$`````````````$@```)("
M`````````````!(```!$`0`````````````2````KP``````````````$0``
M`/$!`````````````!$````=`P`````````````1````T```````````````
M$@```"H#`````````````!$```#A```````````````2````IP``````````
M````$@````4!`````````````!(```"(`0`````````````2````E@$`````
M````````$@```(,"`````````````!(```!&```````````````2````<0$`
M````````````$@```%L!`````````````!(```#'`0`````````````2````
M[`$`````````````$@```"`"`````````````!(```!8```````````````B
M````9`0``%RP````````$``9`!($``#,2@``/`$``!(`#@")!```H$```%@'
M```2``X`4P```/`8``#(`@``$@`.`(D#``!\,@``!````!(`#@"G`P``^$<`
M`-0"```2``X`.@0``$BP````````$``9`*\$``"`,@``D`(``!(`#@!O!```
M2+`````````0`!D`F@,``!`U```P````$@`.`+T#```L/```H````!(`#@`>
M!```4$\```0````1`!``2`0``)!,``!4`0``$@`.`%,$```(,0``6````!(`
M#@!;!```7+`````````0`!D`A`0``%RP````````$``9`)T$```H/P``>`$`
M`!(`#@#&!```S#P``'0````2``X`+00```"P````````$``8`.$#``!`-0``
MJ`$``!(`#@"6!```2+`````````0`!@`O`0``$2P```$````$0`8`#,$``"X
M&P```````!(`#@![!```"$P``(@````2``X`+P0```"P````````(``8`/<#
M```$/P``)````!(`#@#+`P``8#$``!P!```2``X`[0,``.1-``!0`0``$@`.
M`&,$``!<L````````!``&0#.!```Z#8``$0%```2``X``%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE
M`&%B;W)T`%]?<F5G:7-T97)?871F;W)K`%]?865A8FE?=6YW:6YD7V-P<%]P
M<C``7U]S=&%C:U]C:&M?9F%I;`!S=')N8VUP`%]?96YV:7)O;@!L<W1A=#8T
M`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H
M:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4&5R;%]N97=84P!097)L7VYE=UA3
M7V9L86=S`&)O;W1?1'EN84QO861E<@!03%]C=7)R96YT7V-O;G1E>'0`<F5A
M9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]A
M96%B:5]U;G=I;F1?8W!P7W!R,0!?7VUE;6UO=F5?8VAK`')E86QL;V,`9V5T
M<&ED`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``
M<W1R<F-H<@!M96UC<'D`7U]V9G!R:6YT9E]C:&L`97AI=`!S=&1E<G(`;'-E
M96LV-`!R96%D`&UE;6-M<`!G971U:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?
M;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E
M`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A
M;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U;@!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R
M87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\`;&EB8RYS
M;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB9V-C7W,N<V\N,0!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA
M;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7V)S<U]S=&%R
M=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S7V5N9%]?`%]?
M8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D
M:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'0T-?,RXU`$=,24)#7S(N,S0`
M1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,X+C(O87)M=C9L+6QI;G5X
M+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%``````````(``0`"``(``@`!``$`
M`P`!``$``@`!``$``@`!``(``0`!``(``@`"``(``0`$``(``0`!``$``0`!
M``$``@`"``(``@`!``(``@`%``(``@`!``(``@`!``(``@`"``(``@`"``0`
M`@`!``(``0`"``(``@`!``(``0`"``(``0`"``(``0`&``,``@`"``(``@`"
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!`````0`!`&<#```0````(````!1I:0T```4`VP0`
M```````!``$`>P,``!`````@````529Y"P```P#E!`````````$``P!=`P``
M$`````````"TD98&```&`.T$```0````LY&6!@``!`#X!```$````!1I:0T`
M``(`VP0```````"@K0``%P```*2M```7````_*\``!<````$L```%P```!2P
M```7````&+```!<````@L```%P```"2P```7````*+```!<````LL```%P``
M`#"P```7````.+```!<````\L```%P```$2P```7````R*\``!4+``#,KP``
M%0P``-"O```5$P``U*\``!49``#8KP``$QT``-RO```5'@``X*\``!4?``#D
MKP``%2<``.BO```5*0``[*\``!4]``#PKP``%3X``/2O```50```^*\``!5-
M``#4K@``%@,``-BN```6!```W*X``!8%``#@K@``%@8``.2N```6!P``Z*X`
M`!8(``#LK@``%@D``/"N```6#```]*X``!8-``#XK@``%@X``/RN```6#P``
M`*\``!80```$KP``%A$```BO```6$@``#*\``!84```0KP``%A4``!2O```6
M%@``&*\``!87```<KP``%A@``""O```6&@``)*\``!8;```HKP``%AP``"RO
M```6(```,*\``!8A```TKP``%B(``#BO```6(P``/*\``!8D``!`KP``%B4`
M`$2O```6)@``2*\``!8H``!,KP``%BH``%"O```6*P``5*\``!8L``!8KP``
M%BT``%RO```6+@``8*\``!8O``!DKP``%C```&BO```6,0``;*\``!8R``!P
MKP``%C,``'2O```6-```>*\``!8U``!\KP``%C8``("O```6-P``A*\``!8X
M``"(KP``%CD``(RO```6.@``D*\``!8[``"4KP``%C\``)BO```600``G*\`
M`!9"``"@KP``%D,``*2O```61```J*\``!9%``"LKP``%D8``+"O```61P``
MM*\``!9)``"XKP``%DH``+RO```62P``P*\``!9,``#$KP``%DT```A`+>E_
M`0#K"("]Z`3@+>4$X)_E#N"/X`CPON6XF````,:/X@G*C.*X^+SE`,:/X@G*
MC.*P^+SE`,:/X@G*C.*H^+SE`,:/X@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/
MX@G*C.*0^+SE`,:/X@G*C.*(^+SE`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE
M`,:/X@G*C.)P^+SE`,:/X@G*C.)H^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8
M^+SE`,:/X@G*C.)0^+SE`,:/X@G*C.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*
MC.(X^+SE`,:/X@G*C.(P^+SE`,:/X@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/
MX@G*C.(8^+SE`,:/X@G*C.(0^+SE`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE
M`,:/X@G*C.+X][SE`,:/X@G*C.+P][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@
M][SE`,:/X@G*C.+8][SE`,:/X@G*C.+0][SE`,:/X@G*C.+(][SE`,:/X@G*
MC.+`][SE`,:/X@G*C.*X][SE`,:/X@G*C.*P][SE`,:/X@G*C.*H][SE`,:/
MX@G*C.*@][SE`,:/X@G*C.*8][SE`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE
M`,:/X@G*C.*`][SE`,:/X@G*C.)X][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H
M][SE`,:/X@G*C.)@][SE`,:/X@G*C.)8][SE`,:/X@G*C.)0][SE`,:/X@G*
MC.)(][SE`,:/X@G*C.)`][SE`,:/X@G*C.(X][SE`,:/X@G*C.(P][SE`,:/
MX@G*C.(H][SE`,:/X@G*C.(@][SE`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE
M`,:/X@G*C.((][SE`,:/X@G*C.(`][SE`,:/X@G*C.+X]KSE`,:/X@G*C.+P
M]KSE`,:/X@G*C.+H]KSE`,:/X@G*C.+@]KSE`,:/X@G*C.+8]KSE`<J@XW!`
M+>D,P$W@R`^,Y5C"G^4HT$WB5#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-
MXA0@C>(<`(WB-%*?Y0`PD^4D,(WE`#"@X];__^LD(I_E!5"/X`(@E><<,I_E
M#""-Y0,PE><"$*#A`P"@X1`PC>5R#0#K!#*?Y0,PE><`0-/E``!4XT\```IP
M+QWN\#&?Y1P`G>4#,)_G`T"`X@,@DN<$`(#BSC/2Y0<!<.,#,(/CSC/"Y6``
M`(H``:#AH?__ZP`PH.&\(9_E&!"=Y0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=
MY0``D>4,P(_@!5"/X`[@C^`!`%+C84"#Z`0PC.54``#:!`!!X@S`@^("`8#@
M!."QY0$`4.$$X*SE^___&@/`@N(`X*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`
MX(WE`1"/X`SA@^<&___K``!0XRD```I$49_E(&"-X@50C^`,`)7E3?__ZP!`
MH.$P`9_E!A"@X0``C^#0`P#K``!0XR````H<,9_E`S"/X`P`D^7E_O_K(/__
MZPPAG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB
M<("]Z/[^_^O<()_E``!0XP(@C^`,`(+E'P``"A/__^MP+QWNQ#"?Y0,PG^<#
M,)+GKD;#Y:/__^H,`)7EX?[_Z]+__^H(`)7E``!0XP$```KO"P#KV?__ZI0`
MG^4&$*#A``"/X*0#`.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)7G``"/
MX`,0H.$,,(WE-?__ZP3`H..P___J`0"@XUO__^L>___KJ)4``"`!``!\E0``
M``$``!@!```H`0``2)8``'R6``!HE@``&#D``!@Y```@E@``F!(``/25```X
M-@``R)4``"R4``!\E0``\)0``"0U```L`0``_#8```"PH.,`X*#C!!"=Y`T@
MH.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<M___KC?[_
MZ]22```T`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!D_[_ZKR2```$`0``
M+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>
M_R\!$_\OX1B4```4E```B)(```@!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?
MH.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_AU),`
M`-"3```XD@``#`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q$!RJ#C
M$$`MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G^?[_Z\?__^L!
M(*#C&#"?Y0,PC^``(,/E$("]Z(23``#\D0``,`$```B3```XDP``S?__Z@``
M```!RJ#C\$\MZ0S`3>!`#8SE4"R?Y5`\G^4"((_@`S"2YZ??3>(`$*#A$,"-
MX@`PD^64,HWE`#"@XPP@H.$`0*#C0`"`XH!0@>)`0!#I+C2@X?\\`^(N/(/A
M#G2@X0X\@^'_>`?B"`"`XC;OO^8',(/A!0!0X0#@@N4$0(+E"#""Y0Q`@N40
M((+B[O__&H(_C.(<0)WE>,"=Y00PC>6(,)WE&%"-X@@0C>4%`*#A`Q"@X0R0
MH.%\()WE&+"=Y8"`G>6$<)WEC."=Y1!@G>44H)WE`$"-Y0Q0C>4!``#J!;"@
MX0!`C>4`0*#C`3"@X3S`D.4X$)#E"%"PY71`@.4$0)#E!1`AX`D0(>`$P"S@
M!A`AX`+`+.`*P"S@")"@X0.`H.&A/Z#AC#"#X0$0D>`#$('A!#"=Y0<@H.$`
M`%/A#G"@X0M@H.$`X*#C`*"=Y7`0@.7A__\:"!"=Y0Q0G>4`D)'E"#N?Y0@@
M%>4@X)'EJ6V@X0$(D>D0@)'E&*"1Y0,@DN"`8H;A#B"2X(EBAN$,P)'E`F"6
MX`H@*.`K0:#A"R`"X`H@(N`,3X3A`F"6X`M/A.$8()WE*<&@X0#/C.$$`"C@
M`R"2X`D``.`*()+@"``@X`G/C.$``)+@"""5Y0S@).`#()+@!N`.X`3@+N`(
M()+@Y@V`X`X@DN#@[8+@$""5Y0,@DN`$()+@9D$LX`!`!.`,0"3@!""2X!A`
ME>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C.`@P)7E`\"<
MX&;!C.!N82#@`F`&X`!@)N`&P)S@*&"5Y6(AH.$#8);@``"6X&YA(N`$8`;@
M;F$FX.3-C.`&`)#@[&V`X#``E>4#`)#@;@&`X&3A(N`,X`[@`N`NX`X`D.`X
MX)7E;,&@X0/@GN`"()[@9.$LX`;@#N!DX2[@Y@V`X`X@DN#@[8+@0""5Y0,@
MDN!D(8+@9D$LX`!`!.`,0"3@!""2X$A`E>5@`:#A`T"4X`S`E.!F02#@#D`$
MX&9!).#N+8+@!,"<X.)-C.!0P)7E`\"<X&;!C.!N82#@`F`&X`!@)N`&P)S@
M6&"5Y6(AH.$#8);@``"6X&YA(N`$8`;@;F$FX.3-C.`&`)#@[&V`X&``E>4#
M`)#@;@&`X&3A(N`,X`[@`N`NX`X`D.!HX)7E;,&@X0/@GN`"()[@9.$LX`;@
M#N!DX2[@Y@V`X`X@DN#@[8+@<""5Y0,@DN!D(8+@9D$LX`!`!.`,0"3@!""2
MX'A`E>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C."`P)7E
M`\"<X&;!C.!N82#@`F`&X`!@)N`&P)S@Y&V,X(C`E>5B(:#A`\"<X```G.!N
MP2+@!,`,X&[!+.`,`)#@YLV`X)``E>4#,)#@9`$BX`8``.`"`"#@;C&#X``P
MD^#L?8/@F`"5Y2PXG^5F8:#A`P"0X*#@E>4"()#@9`$FX`P`(.``()+@`P">
MX&0!@.#G[8+@J$"5Y6PA)N`'("+@`@"0X&<AH.$#0)3@L'"5Y09`E.!L82+@
M#F`FX.X-@.`&0)3@`V"7X&QAAN"X<)7EX,V$X&Y!(N``0"3@!&"6X&`!H.$#
M0)?@`D"4X,!PE>7L+8;@;F$@X`Q@)N`&8)3@`T"7X&Y!A.#(<)7E;.$@X`+@
M+N#B;8;@#D"4X&(AH.$#X)?@``">X-!PE>5LX2+@!N`NX`[@D.`#`)?@YDV$
MX-APE>5L`8#@9L$BX`3`+.#D[8[@#`"0X&1!H.$#P)?@`B"<X.!PE>5FP23@
M#L`LX`S`DN`#()?@[@V`X.APE>5F(8+@;F$DX`!@)N#@S8S@!B"2X&`!H.$#
M8)?@!&"6X/!PE>5N02#@#$`DX`1`EN`#8)?@["V"X&YAAN#X4)7E;.$@X`+@
M+N#B383@#N"6X&(AH.$#4)7@`%"5X!AAG>5L`2+@!``@X.3MCN```)7@`V"6
MX.Y=@.!LP8;@9`$BX"!AG>4.`"#@;N&@X2AQG>4``)S@`V"6X&3!+N`"();@
M!<`LX.4-@.`,P)+@`R"7X.!MC.!D(8+@9<$NX#!!G>4`P"S@#,"2X&`!H.$#
M0)3@YBV,X`[@E.!EP2#@.$&=Y0;`+.`,P)[@`^"4X&7ACN!F02#@0%&=Y0)`
M).#BS8S@!.">X&(AH.$#4)7@``"5X&9!(N!(49WE#$`DX`1`D.`#`)7@[.V.
MX/`UG^50<9WE9@&`X&QA(N!N4:#A#F`FX.Y-A.`&8)#@;.&%X0,`E^`"`)#@
M6'&=Y>0MAN`$X`[@;&$%X`;@CN$.X)#@`W"7X&0!A>%D807@;,&'X`(``.!@
M<9WE!@"`X>+MCN`,`)#@8B&@X0/`E^`%P)S@9%&"X61A`N!H<9WE#E`%X`90
MA>'N#8#@#%"5X`-PE^!NP8+A;F$"X&1!A^``P`S@<'&=Y0;`C.'@787@!$"<
MX&`!H.$#P)?@`L"<X.4MA.!N08#A;F$`X'AQG>4%0`3@!D"$X0Q`E.`#<)?@
M9<&`X65A`.!NX8?@`L`,X(!QG>4&P(SAXDV$X`[@G.!B(:#A`\"7X`#`G.#D
M#8[@9>&"X65A`N"(<9WE!.`.X`;@CN$,X)[@`W"7X&3!@N%D80+@95&'X`#`
M#."0<9WE!L",X>#MCN`%4)S@8`&@X0/`E^`"P)S@[BV%X&11@.%D80#@F'&=
MY0Y0!>`&4(7A#%"5X`-PE^!NP8#A;F$`X&1!A^`"P`S@H'&=Y0;`C.'B787@
M!$"<X&(AH.$#P)?@`,"<X.4-A.!N08+A;F$"X*AQG>4%0`3@!D"$X0Q`E.`#
M<)?@9<&"X65A`N!NX8?@`,`,X+!QG>4&P(SAX$V$X`[@G.!@`:#A`\"7X`+`
MG.#D+8[@9>&`X65A`."X<9WE!.`.X`;@CN$,X)[@`W"7X&3!@.%D80#@95&'
MX`+`#.#`<9WE!L",X>+MCN`%4)S@8B&@X0/`E^``P)S@[@V%X&11@N%D80+@
M#E`%X`90A>$,4)7@;L&"X6YA`N``P`S@!L",X0!@H./(<9WEX%V%X`-PE^!D
M08?@T'&=Y6`!H.$$0)S@`\"7X`+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@
M@>4<8('E;F$`X-AQG>4&0(3A#$"4X&7!@.$#<)?@96$`X`+`#.!NX8?@!L",
MX>!QG>7B383@#L"<X&(AH.'D[8S@`W"7X&7!@N%E80+@``"7X`3`#.#H<9WE
M!L",X0#`G.`#<)?@9`&"X>@RG^5D80+@95&'X`X``.#P<9WE!@"`X>[-C.`%
M`)#@;N&@X0-0E^`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!
MAN!L(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4
MX`-`EN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@
M&&*=Y64!(N`.`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.``
M`)3@;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[A
MAN!E(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"
MX`S`GN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@
M2&*=Y60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.``
M`)[@;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!B
MG>7@78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"
MX`S`GN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@
M>&*=Y64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE[`V`X`Q@)N!L
MP:#A!N">X`-0E>!D82S@`&`FX`(@E>`&()+@`&"@XXA2G>7@[8[@`S"5X&"A
MBN`),)/@8`$LX`X`(.!D,8/@`#"3X.XM@N#B/8/@(`"1Y0L@DN!N@8C@&*"!
MY1"`@>4`,('E"""!Y4P@G^4`P)S@,#"?Y0(@C^`@P('E)&"!Y0,PDN<`()/E
ME#*=Y0(@,^``,*#C`0``&J??C>+PC[WHD/O_ZWB1```@`0``F7F"6J'KV6[<
MO!N/UL%BREB%```!RJ#C\$<MZ0S`3>#@#XSER#"?Y0"`4.(#,(_@*P``"KP@
MG^4",)/G`)"3Y0``6>,H```*`%#8Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``
M&@!`F>4``%3C#```"@E@H.$%(*#A"!"@X00`H.&1^__K``!0XP(``!H%,-3G
M/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`A0H.$!,/7E``!3XST`4Q/[
M__\:"%!%X.;__^H)8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"$"@X>W_
M_^H)0*#AZ___ZO2$```<`0```<J@XQ!`+>D,P$W@B`^,Y8P@G^6,,)_E`B"/
MX'#03>(#,)+G#1"@X0`PD^5L,(WE`#"@XP!`H.%,^__K``!0XP``H!,$```:
M$#"=Y0\Z`^(*"E/C`0E3$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"
M(#/@`#"@XP<``!IPT(WB$("]Z`(0H.,$`*#A[OK_ZQ`/;^&@`J#A[O__ZB;[
M_^L,A```(`$``,"#```!RJ#C\$`MZ0S`3>!P#XSE8"&?Y6`QG^4"((_@`S"2
MYWS03>(`4%#B`#"3Y70PC>4`,*#C`@``"@`PU>4``%/C"@``&C0AG^4L,9_E
M`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C0@``&GS0C>+P@+WHG?K_ZP!@4.+Q
M__\*!@"@X2#[_^L``%#C*P``"A,PT.430(#B+@!3XP(``!H!,-3E``!3X_3_
M_PH3,-#E+@!3XR8```H%`*#AROK_ZP!PH.$$`*#AQ_K_ZP!PA^`"<(?B!P"@
MX>KZ_^L$0(WE`$"@X9PPG^4'(*#A`A"@XP,PC^``4(WE!OO_ZP0`H.$($(WB
MJ?K_ZP$`<.,$`*#A`P``"A@PG>4/.@/B`0E3XQ(```JS^O_K!`"@X9;Z_^L&
M`*#A]/K_ZP``4./3__\:!@"@X</Z_^L%`*#AV?K_Z[S__^H!,-3E+@!3X]7_
M_QH",-3E``!3X\3__PK1___JH___Z^O__^K%^O_K7(,``"`!```H@P``I",`
M``'*H.,00"WI#,!-X.@/C.5P3QWN;!"?Y6PPG^4!$(_@`S"1YQ#03>)@`)_E
M##"-Y0,@H.$``)_G5#"?Y500G^4``)3G`S"/X`$0C^#4^O_K`,"@XT``G^5`
M,)_E``"?YSP@G^4\$)_E`S"/X```E.<"((_@"!"-Z`$0C^!Q^O_K$-"-XA"`
MO>C0@0``%`$``,B"``"`8P``R"(``*""``"X)0``K!H``+0B```!RJ#C\$$M
MZ0S`3>```(SE(``,Y0%PH.$`$9_E`#&?Y0':3>((T$WB`1"/X`,PD><`8*#A
M`0J-X@0`@.(`,)/E`#"`Y0`PH./8`)_E!("-X@@0H.'0()_E``"/X)GZ_^L`
M0%#B!P``V@A0C>(!,$3B`\"%X`0@7.4``%+C%P``&@``4^,4```:<`\=[IPP
MG^4'(*#A`S"?YP80H.$#`)#G'_K_ZX@@G^5T,)_E`B"/X`$:C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.,2```:`=J-X@C0C>+P@;WH`T"@X00@H.$O$*#C
M"`"@X9#Z_^L``%#CX___"G#/'>XT`)_E!#"@X0``G^<((*#A!A"@X0``G.<R
M^O_KX?__ZD[Z_^L8@0``(`$``$`B``#_#P``O($``)2```!,@0```<J@X_!/
M+>D,P$W@T`^,Y0%`H.$8(I_E&#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@
MXP`PT>4`4*#A/0!3XP%`@0($`*#A"OK_ZPT0H.$`8*#A!0"@X:;^_^O8<9_E
M`)!0X@=PC^!````*`?K_ZP``5N$W``":P#&?Y0"`G>4#<)?G"(&@X0`PU>4`
M`%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`
MAN(#`(#@`&"7Y1+Z_^L``%#C"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3
MXP``4Q,`,,'E!@``"@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH],*#C
M`2"@X0`PP>4!,-3D``!3XP$PXN7[__\:$"&?Y0`QG^4"((_@`S"2YP`@D^4$
M,)WE`B`SX``PH.,W```:#-"-XO"/O>@!D$GB`3#4Y```4^,!,.GE^___&N[_
M_^K(,)_E`W"7YP"`E^4`,)CE``!3XR8```H(,*#A!""SY0D0H.$``%+C`9")
MXOK__QH#$('B`;&@X9@PG^4#,(_@`""3Y0``4N,0```:`2"@XPL`H.$`((/E
MT?G_ZP"@4.+5__\*"!"@X0F!H.$+,*#A"""@X??Y_^L`H(?E`#"@XP"0C>4!
MD(GB"3&*YZ'__^H+$*#A"`"@X?'Y_^L``%#C`*"@X0``A^7#__\*"8&@X?'_
M_^H#D*#A"+"@X]W__^JZ^?_KZ'\``"`!``"@?P``'`$``-!^``#<?P``/!"?
MY3PPG^4!$(_@`S"1YW#/'>X#(*#A"-!-XB@`G^4$,(WE``"?YR`PG^4@$)_E
M``"<YP,PC^`!$(_@"-"-XLKY_^JP?0``%`$``*1^``!<7P``I!X```'*H./P
M0"WI#,!-X```C.4!RDSB``",Y3``#.7@()_EX#"?Y0+:3>(<T$WB`B"/X`,P
MDN<"&HWB%!"!X@`PD^4`,('E`#"@XZ#Y_^NXP)_EN#"?Y0%*C>(,P(_@$$"$
MX@$0C>@"$*#C!`"@X:`@G^4#,(_@#&"-XJ#Y_^L$`*#A`2J@XP80H.&6^?_K
M`$!0X@!0H+,*``"Z`7"$X@<`H.%R^?_K`%!0X@4```H',*#A!A"@X00@H.$Y
M^?_K`#"@XP0PQ>=,()_E.#"?Y0(@C^`"&HWB`S"2YQ00@>(`()/E`#"1Y0(@
M,^``,*#C`P``&@4`H.$"VHWB'-"-XO"`O>A=^?_K-'T``"`!``!\'@``6!X`
M``$0``"4?```M___Z@'*H./P3RWI#,!-X```C.6H``SE1,*?Y40BG^5"W4WB
M!-!-X@S`C^``8*#A-`*?Y0(@G.=!/8WB$("-X@%`H.$``(_@"!"@X3PP@^(`
M()+E`""#Y0`@H..U_?_K+Q"@XP!0H.$&`*#AX?C_ZP``4.,2```*\`&?Y080
MH.$``(_@[?[_ZP8`H.'@(9_ET#&?Y0(@C^!!'8WB`S"2YSP0@>(`()/E`#"1
MY0(@,^``,*#C:0``&D+=C>($T(WB\(^]Z`0`H.$8^?_KI!&?Y0$0C^`G^?_K
M`$!0XN7__PH`,-3ED)&?Y8"@C>(``%/C"9"/X`1P2N([```*``!5XP0```H$
M$*#A!0"@X4SY_^L``%#C*P``"@0`H.'E^/_K`3!`X@,PA.`#`%3A`+"@X0#`
MH#,`,(0P`1"$,@,``#H(``#J`P!1X0#`P^4"```*`2!SY2\`4N/Y__\*!`"@
MX=3X_^L`L*#A!@"@X='X_^L+`(#@`0"`X@$*4..]__\J^`"?Y0DPH.$``(_@
M`2J@XP(0H.-!`(WI`$"-Y0<`H.$/^?_K"!"@X0<`H.&R^/_K``!0XP,``!I@
M,!KE#SH#X@()4^,5```*M!"?Y0``H.,!$(_@Y_C_ZP!`4.*E__\*`##4Y0``
M4^/#__\:``!5XQ8```H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5___J`3#5
MY0``4^/J__\*]___Z@$0H.,'`*#AD/C_ZP``4./D__\:4`"?Y0<0H.$``(_@
M?O[_ZP<`H.&X^/_KCO__ZCA`G^4!L*#C!$"/X,'__^J^^/_K''P``"`!``!\
M'0``3!T``+![```,'0``\!P``&`<```,'```M!L``)`;``!D&P```<J@XQ!`
M+>D,P$W@^`^,Y2\0H.,`0*#A8/C_ZP``4.,!0(`2!`"@X1!`O>B:^/_J`<J@
MXW!`+>D,P$W@``",Y1@`#.5P(9_E<#&?Y0':3>("((_@"-!-X@$:C>(#,)+G
M`&!0X@00@>(`,)/E`#"!Y0`PH.,O```*`##6Y0``4^,L```*9OC_ZP$@@.(!
M"E+C`$"@X3@``(H$4(WB!A"@X04`H.%D^/_K`3!$X@,PA>`%`%/A!P``F@`0
MH.,"``#J!0!3X0$0P^4"```*`2!3Y"\`4N/Y__\*+Q"@XP4`H.$N^/_K``!0
MXR4```H%`%#A`#"@@P`PP(4%`*#A9OC_Z[P@G^6T,)_E`B"/X`$:C>(#,)+G
M!!"!X@`@D^4`,)'E`B`SX``PH.,B```:`=J-X@C0C>)P@+WHB""?Y7PPG^4"
M((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XQ0``!I@`)_E``"/X`':
MC>((T(WB<$"]Z$?X_^H``*#CWO__ZD0@G^4P,)_E`B"/X`$:C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.,@`)\%``"/`.S__PI#^/_K8'D``"`!``"H>```
M<'@``,`9```D>```>!D```'*H.-P0"WI#,!-X.@/C.7$))_EQ#2?Y0(@C^#`
M5)_E`S"2Y[QDG^4(T$WB!5"/X``PD^4$,(WE`#"@XP9@C^`-0*#A!!"@X08`
MH.&>_/_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"
MY_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/X`00H.$&`*#A
MB/S_ZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q
M__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$$*#A!@"@X7+\
M_^L``%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__
M"@0P@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@X08`H.%<_/_K
M``!0XPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$
M,(/B!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&`*#A1OS_ZP``
M4.,.```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#
MX@0@D^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@X3#\_^L``%#C
M#@``"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($
M()/E``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.$:_/_K``!0XPX`
M``I\,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3
MY0``4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#A!/S_ZP``4.,.```*
M)#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X>[[_^L``%#C#@``"LPQ
MG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2
MXP0@@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.'8^__K``!0XPX```IT,9_E
M`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$
M((/D^___&NO__^I@89_E!F"/X`00H.$&`*#APOO_ZP``4.,.```*'#&?Y0`0
MG>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___J#`&?Y000H.$``(_@K?O_ZP`04.("```*^`"?Y0``C^#J_/_K
M\`"?Y000H.$``(_@I/O_ZP`04.("```*W`"?Y0``C^#A_/_KU`"?Y000H.$`
M`(_@F_O_ZP`04.(2```*P`"?Y0``C^#8_/_KN""?Y60PG^4"((_@`S"2YP`@
MD^4$,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0C>)P0+WHR/S_
MZH0`G^4$$*#A``"/X(+[_^L`$%#BZ?__"G``G^4``(_@O_S_Z^7__^H%]__K
MP'<``"`!``"L=P``1!D``!P!``#T&```I!@``%@8```(&```P!<```07```<
M%P``T!8``(06``"P%0``W!4``+`5``#,%0``S!4``,@5``#L%```8',```@7
M```(%0``=!4``/@4```!RJ#C!.`MY0S`3>#P#XSE>""?Y7@PG^4"((_@=`"?
MY0S03>(#,)+G#1"@X0``C^``,)/E!#"-Y0`PH.-1^__K``!0XP4```H``-#E
M``!0XS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XP$``!H,T(WB!/"=Y,?V_^M\<@``(`$``%04```L<@```<J@XP\`
M+>D$X"WE#,!-X/`/C.5(()_E2#"?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@
MXS``G^4PP)_E%#"-X@``C^``,(WE#`"0YP(0H.,0()WE``"0Y93V_^O_`*#C
MYO;_Z]AQ```@`0``M'$``"0!````P*#C\$<MZ0'HH.,,P$W@#N!,X`'*3.(`
M`(SE#@!<X?O__QHX``[E`A"@XW3AG^5TP9_E`=A-XAC03>(.X(_@#,">YP%(
MC>(`(*#C`#"@XP#`G.44P(3E`,"@XP`0C>4`@*#AAO;_ZP%@4.(`<,'BQR^@
MX<<_)N`",%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"<,?@``!7XQ1`A.(W``"Z
M")&?Y0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y7#V_^L!`''C`0!P`S(```H)
M(*#A!1"@X0@`H.$P]O_K`0!PXRD```H'`%#C'P``F@@`0.(`0)7@'```*K2@
MG^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@X?CU_^L``%#C]O__
M&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G%,",X@`@D^4`,)SE
M`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!`'?C`0AV`\G__QH`
M`.#C`!"@X>G__^HH`)_E``"/X'S__^L@`)_E``"/X'G__^L\]O_K1'$``"`!
M```(``$`Q'$``$1P``!H$@``3!(```'*H.,00"WI#,!-X/@/C.7K]?_K#O;_
MZP``4.,``)`5$("]Z`'*H./P0"WI#,!-X-`/C.4\(9_E/&&?Y3PQG^4"((_@
M'-!-X@,PDN<&8(_@`%"@X08`H.$0$(WB`#"3Y10PC>4`,*#CD/K_ZP!`4.("
M```*`##4Y0``4^,.```:_""?Y?0PG^4"((_@`S"2YP`@D^44,)WE`B`SX``P
MH.,S```:!1"@X=@`G^4``(_@'-"-XO!`O>B^^__J!1"@X>_U_^L``%#C"@``
M"K@@G^6H,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C(```&AS0C>+P@+WH
M!0"@X<OU_^L`<*#A!`"@X<CU_^L`<(?@`G"'X@<`H.'K]?_K;!"?Y6PPG^4!
M$(_@!R"@X0A`C>4#,(_@!!"-Y0!0C>4"$*#C`$"@X03V_^M(()_E+#"?Y0(@
MC^`#,)+G`""3Y10PG>4"(#/@`#"@XP00H`$&`*`!SO__"M?U_^M\;P``]!$`
M`"`!```T;P``E!$``.AN```P$```*!```&QN```!RJ#C\$\MZ0S`3>#@#HSE
MM":?Y?S03>("((_@L$"-X@+@H.$$X*#AH!:?Y2`@C>6<QI_EG":?Y0$0C^`"
M()'G#,"/X`PPC.(88(SBI'"-X@`@DN7T((WE`""@XQP`C>4'`)/H!P"'Z`\`
MMN@/`*[H`P"6Z##`C.*84(WB`P".Z`<`G.@'`(7H3`:?Y2B`C>(($*#A``"/
MX!WZ_^L`8%#B`@``"@`PUN4``%/C*0$`&ESU_^M_]?_K``!0XX@```H`8)#E
M``!6XX4```H&`*#A;_7_ZX`@H.$!L(+B"P"@X9+U_^L`P-;E`%"@X0``7.,+
MD*`1)`"-%20!``K<I9_E"J"/X`L@H.$*,*#A`A"@XP4`H.$`P(WEJ/7_ZPL`
M6>$)(*`A"R"@,0(P2^(+$$+@`<#VY0(0@>(",$/@`@!1X0&P@R`"L(,P``!<
MXP)0A>+K__\:B`6?Y0``C^`"``#J!`"TY0``4.,-```*"!"@X>?Y_^L`4%#B
M^/__"@`PU>4``%/C]?__"AOZ_^L``%#C\O__"@4`H.%;]?_K`$!0X@T``!H$
M0)?D``!4XPH```H`,-3E``!3X]0```H$`*#A#?K_ZP``4./U__\*!`"@X4WU
M_^L`0%#B\?__"@0`H.$K]?_K)%"=Y0!@H.$%`*#A)_7_ZP!@AN`!:X;B!&"&
MX@8`H.%)]?_K`'"@X=0TG^4&(*#A`S"/X`@PC>7(-)_E`A"@XP,PC^`$,(WE
MO#2?Y0Q0C>4#,(_@`$"-Y5_U_^L'':#C!P"@X<GT_^L!`'#C`P``&G?U_^L`
MP)#E$0!<X[```!H($*#A!P"@X3[U_^L`0%#B,0``"G0TG^4@()WE`A"@XP,@
MDN<<,)WE``"2Y6`DG^4`,)/E`B"/X`!PC>4H]?_K`%"@XTPDG^4D-)_E`B"/
MX`,PDN<`()/E]#"=Y0(@,^``,*#C^P``&@4`H.'\T(WB\(^]Z`OU_^L`8%#B
MC```&@0`E>0``%#C"0``"@@0H.&&^?_K`#!0XOC__PH`,-/E``!3X_+__QH$
M`)7D``!0X_7__QH-`*#C`_7_ZPV0H./48Y_E4\"@XP!0H.$)L*#A!F"/X"0`
MC>5N___J.#"=Y0\Z`^(!"5/CR?__&D!0G>6S]/_K``!5X<7__QHX,)WE@SN@
MX:,[H.$'#5/CP/__&@8`H.'L]/_K`%"@X7P#G^4($*#A``"/X&#Y_^L`$%#B
M?P``"APPG>4``)/ECOO_ZP"@4.)Z```*"@"@X;?T_^L#`%#C`)"@X0P``)I`
M$Y_E!`!`X@``BN`!$(_@$O7_ZP``4.,%```:!`!9XZ4```H)D(K@!3!9Y2\`
M4^.A```*$`.?Y0@0H.$``(_@0_G_ZP``4.,#```*`##0Y3``4^,``%,3!```
M&@H`H.$`$*#CJ?3_ZP"`4.)<```:V!*?Y=@"G^4!$(_@``"/X'7Z_^O1]/_K
MR#*?Y<@BG^4#,(_@!#"-Y<`RG^4"((_@O**?Y;R2G^6\@I_E"`"-Y0P@C>4"
M$*#C!B"@X04`H.$`<(WE`S"/X,ST_^L*H(_@"9"/X`B`C^`.``#JY?3_ZP`P
MD.41`%/C#P``&K?T_^L`P*#A`4"$X@(0H.,*,*#A!B"@X04`H.&`$8WH$)"-
MY0Q`C>6Y]/_K!QV@XP4`H.$C]/_K`0!PX^O__PH'`*#A3_3_ZS0"G^4%$*#A
M``"/X$7Z_^L%`*#A7O[_ZV7__^H#0*#A,/__ZEWT_^N`(*#A`;""XNS^_^H@
M$)WEP"&?Y1PPG>4"()'G`#"3Y0``DN7L(9_E`A"@XX`0C>@"((_@?/3_ZU+_
M_^I*_O_KU"&?Y7`QG^4"((_@`S"2YP`@D^7T,)WE`B`SX``PH.-.```:!@"@
MX?S0C>+P3[WH7O3_ZB0`C>7N_O_J'#"=Y0"@D^6!___JO?W_ZP"@4>(`D*#A
MGO__N@"PH.,*(%#B`##*X@@`H.$`L(WE5?3_ZY`0C>(&(*#C"`"@X1P0C>47
M]/_K!@!0XQP0G>4T```:2#&?Y9`@G>4#`%+AC/__&K0@T>$X,9_E`P!2X8C_
M_QHR(%GB`##*X@@`H.$`L(WER$"-XC_T_^LH(*#C"`"@X000H.$"]/_K*`!0
MXR```!H`,9_E`!&?Y0,PC^`$,(WE^#"?Y0$0C^`,$(WE!B"@X0(0H.,%`*#A
M"$"-Y0!PC>4#,(_@\+#-Y5'T_^N;___J'#"=Y020D^4``%GC6?__"@D`H.'_
M\__K`P!0XU7__YJL$)_E!`!`X@``B>`!$(_@6_3_ZP``4.,)H*`!3?__ZA[T
M_^N,`)_E``"/X%?]_^L(;@``Z&T``"!O```@`0``"`\``+P/````#P``O`X`
M`*`-``"0#@``)`$``'P.``!P:P``@`T``.`-``"D#0``$`P``+0-``#0"P``
M=`L``/@-```8#0``(`T``,0-```P"P``H`H``(P+``"\:````$-!0TA%``"`
M"0``!`P``"`+``#0"@``O`H```'*H.-P0"WI#,!-X.@/C.5<(I_E7#*?Y0(@
MC^`#,)+G"-!-X@`PD^4$,(WE`#"@XW!/'>X-8*#A/#*?Y3P"G^4#,)_G!A"@
MX0-0E.<``(_@:##5Y6DPQ>57^/_K``!0XP(```H`,-#E,0!3XV4```J>^__K
M"#*?Y0,PG^<#4)3G`!*?Y04`H.$#,*#C`2"@XP$0C^!^\__K`%!0X@P```H0
M()7EX#&?Y0`0DN4#,)_GV"&?Y0,`E.<"((_@>O/_ZQ`PE>4`$)/E"#"1Y0$%
M$^-8```:N!&?Y0,PH.,!$)_G`2"@XP$`E.>H$9_E`1"/X&?S_^L`4%#B"P``
M"I@!G^4&$*#A``"/X"OX_^L`(%#B0```"H0QG^40$)7E`S"?YP`0D>4#`)3G
M7_/_ZW`QG^5P$9_E`S"?YP$@H.,#4)3G`1"/X`4`H.%"\__K6"&?Y0`0H.$"
M((_@!0"@X5+S_^L`(*#C1#&?Y40!G^4#,)_G!A"@X0,PE.<``(_@:2##Y0WX
M_^LL49_E``!0XP50C^``0*#A"`"%Y1$```H'':#C!`"@X1SS_^L!,(#B$0!0
MXP$`4Q,E``"*_""?Y;0PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,;```:
M"-"-XG"`O>@$`)7EKOW_ZP``4.,`0*#A"`"%Y>?__QJ\`)_E``"/X(CS_^L!
M,-#E``!3XYK__PJ5___JI#"?Y1`@E>4#,(_@!#"3Y0``DN4`$)/EU/C_Z[S_
M_^J(,)_E`S"?YP,`E.==\__KH?__ZF3S_^MT()_E`#"@X0(@C^`$$)+E:`"?
MY00@H.$`$)'E``"/X&WS_^NP9@``(`$``)AG``!,"```8&<``-@)```L9P``
MM`D``/QF``"("0``3`<``+QF``"D9@``.`D``#P)``!L9@``S`8``,!F```(
M90``F`@``"QF``"<90``]&4``%`(```!RJ#C,$`MZ0S`3>#H#XSE#"&?Y0PQ
MG^4"((_@`$"@X00!G^4#,)+G#-!-X@T0H.$``(_@`#"3Y00PC>4`,*#CJ/?_
MZP`P4.(*```*`##3Y0``4^,P`%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!,`,2
M``!3XPH``!JP()_EI#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XR```!H,
MT(WB,("]Z``PU.4``%/C\?__"@0`H.%N^O_K+Q"@XP!0H.''\O_K``!0XP%0
M@!(%`*#A`O/_ZU@0G^4$(*#C`1"/X"[S_^L``%#CXO__&D0@G^4P,)_E`B"/
MX`,PDN<`()/E!#"=Y0(@,^``,*#C`P``&@0`H.$,T(WB,$"]Z-?W_^KZ\O_K
MW&,``"`!``"P!0``=&,``,@%````8P```<J@XQ!`+>D,P$W@^`^,Y8``H./K
M\O_K#GN?[0![@.T.>Y_M`GN`[0Y[G^T$>X#M#GN?[09[@.T.>Y_M`""@XPA[
M@.T->Y_M>""`Y0I[@.T,>X#M$("]Z`$C16<`````B:O-[P````#^W+J8````
M`'94,A``````\.'2PP````````````````'*H./P1RWI#,!-X.`/C.4"D*#A
M`#"@XP%`H.$H$)#E+""0Y8G!@>`!`%SA`B#3X`!0H.$P()#E-!"0Y<D/H.$!
M```J`2"2X@`0H>(L,(7EJ3Z@X8`Q@^$",)/@H!ZAX'@`E>4HP(7E``!0XS`P
MA>4T$(7E.("%`B$``!H_`%GC,0``VD"02>(I8Z#A`7"&X@=SA.`(,*#A!!"@
MX4!`A.(`X)'E!,"1Y0@`D>4,()'E$!"!X@0`4>$`X(/E!,"#Y0@`@^4,((/E
M$#"#XO/__QH!0*#A!0"@X?#S_^L'`%3AZ___&@9M9N`&DXG@"2"@X0<0H.$(
M`*#A;_+_ZWB0A>7PA[WH0'!@X@D`5^$)<*"A.("%X@00H.$'(*#A``"(X&7R
M_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'D$G@!T"$X-7S_^O+___J!'"@
MX>7__^H!RJ#C\$$MZ0S`3>#H#XSE?R#@XR@PD>4P8)'E,W^_YJ,QH.$_,`/B
M`<"#XCB`@>(X`%SC`4"@X0!0H.$V;[_F`R#(YSP``-H`$*#C0"!LX@P`B.`6
M\O_K!`"@X;KS_^LX(*#C`!"@XP@`H.$0\O_K!`"@X?!GQ.&S\__K`S#4Y00`
MH.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4
MX04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E
M(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48
M,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!
MO>CL\?_J`!"@XPP`B.`X(&SBV?'_Z\?__^H(,)_E`S"/X``PD^4T\O_JQ&``
M``A`+>D(@+WH`0`"`#X```!!````#````$$````1````00```"<```!!````
M-@```$$````#````00````8```!!````%0```$$````/````00````X```!!
M````)@```$$````3````00```"D```!!`````@```$$````9````00````H`
M``!!````"P```$$``````````````"5S+R5S````1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+W-E
M;&8O97AE```O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]0
M4D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)
M0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?
M1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)
M4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````;'-E96L@
M9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M`"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(````
M`'!A<FP`````+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`
M````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8Q````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`````M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%
M7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[
M("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?
M34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*
M;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I
M("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S
M(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@
M,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@
M)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O
M9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD
M(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I
M('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,[
M"GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@
M7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N
M<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&
M24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S
M96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&
M24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R
M('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%4@``
M``!54T523D%-10````!414U01$E2`%1-4``O=&UP`````'!E<FQX<VDN8P``
M``!#04-(10``/@```$$````,````00```!$```!!````)P```$$````V````
M00````,```!!````!@```$$````5````00````\```!!````#@```$$````F
M````00```!,```!!````*0```$$````"````00```!D```!!````"@```$$`
M```+````00``````````````@;(!@;"PK`<`````AK(!@;"PJP\`````H+(!
M@;"PKP<`````@;(!@;"PJ@<`````A`(!@;`/L0``````A;(!@;"PKG\`````
M9(?_?["J"8`DBO]_`0```)2+_W^O)K*`$)C_?["PKH#PF/]_L*@;@)B9_W^P
MJQZ`&)O_?["H`X"\F_]_?/__?_"<_W^PKP*`-)__?["P`8"$G_]_</__?YB@
M_W^PL+"`E*#_?VS__W\<H_]_L+"H@$2C_W]H__]_Y*3_?["J`8`@JO]_`(0"
M@+BJ_W]<__]_)*O_?V#__W_@K/]_L+"H@/RL_W^PJP:`;*[_?["O/H"\M?]_
ML*H!@(BX_W^PJ0*`O+G_?["PJ(`\NO]_L+"N@(B[_W^PL*R`T+S_?["PL(#<
MO/]_`0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````H'0``M!P```$```!2
M`P```0```%T#```!````9P,```$```![`P``'0````,%```,````]!4```T`
M``!(3P``&0```*"M```;````!````!H```"DK0``'`````0````$````M`$`
M`/7^_V_P!```!0```)P,```&````W`4```H````^!0``"P```!`````5````
M``````,```#(K@```@```.@!```4````$0```!<````,%```$0```#03```2
M````V````!,````(````'@````@```#[__]O`0``"/[__V^T$@``____;P,`
M``#P__]OVA$``/K__V\.````````````````````````````````````````
M`````````````````*BM```````````````6````%@```!8````6````%@``
M`!8````6````%@```!8````6````%@```!8````6````%@```!8````6````
M%@```!8````6````%@```!8````6````%@```!8````6````%@```!8````6
M````%@```!8````6````%@```!8````6````%@```!8````6````%@```!8`
M```6````%@```!8````6````%@```!8````6````%@```!8````6````%@``
M`!8````6````%@```!8````6````%@```!8````6````%@```!8````6````
M````````````````````````````````````````````````````````````
M````````\!@````````$L```"E!!4BYP;0H`````F)```$!0`````````%$`
M``11``",D```2%```)20````````>)```("0````````"%,``$=#0SH@*%-5
M4T4@3&EN=7@I(#$S+C(N,2`R,#(T,#$R-2!;<F5V:7-I;VX@9F,W9#@W93!F
M9F%D8V$T.6)E8S(Y8C(Q,#=C,65F9#!D839B-F1E9%T`03(```!A96%B:0`!
M*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$9`1H"'`$B`40!`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````X````!0````(```"T`0``M`$``#P#```&``````````0````$
M````-````/;__V\"````\`0``/`$``#L````!@`````````$````!````#X`
M```+`````@```-P%``#<!0``P`8```<````#````!````!````!&`````P``
M``(```"<#```G`P``#X%``````````````$`````````3@```/___V\"````
MVA$``-H1``#8````!@`````````"`````@```%L```#^__]O`@```+02``"T
M$@``@`````<````#````!`````````!J````"0````(````T$P``-!,``-@`
M```&``````````0````(````<P````D```!"````#!0```P4``#H`0``!@``
M`!<````$````"````'P````!````!@```/05``#T%0``#```````````````
M!`````````!W`````0````8`````%@```!8``/`"``````````````0````$
M````@@````$````&````\!@``/`8``!8-@`````````````(`````````(@`
M```!````!@```$A/``!(3P``"```````````````!`````````".`````0``
M``(```!03P``4$\``/1!``````````````0`````````E@````$````"````
M1)$``$21``!(```````````````$`````````*$````!``!P@@```(R1``",
MD0``Z`````X`````````!`````````"L`````0````(```!TD@``=)(```0`
M``````````````0`````````M@````X````#````H*T``*"=```$````````
M```````$````!````,(````/`````P```*2M``"DG0``!```````````````
M!`````0```#.````!@````,```"HK0``J)T``"`!```'``````````0````(
M````UP````$````#````R*X``,B>```X`0`````````````$````!````-P`
M```!`````P````"P````H```2```````````````!`````````#B````"```
M``,```!(L```2*```!0```````````````0`````````YP````$````P````
M`````$B@``!6```````````````!`````0```/`````#``!P``````````">
MH```,P```````````````0`````````!`````P``````````````T:`````!
2``````````````$`````````
